function nefdlp(loopdir); 
%NEFDLP Display all loop results
%       This funtions displays all simulation loop data in directory loopdir.
%
% 		For example:
%
%          NEFDLP('loop');
%
% See also NEFCON.  
   
% Author: Andreas Nuernberger, TU Braunschweig, August 1996; a.nuernberger@tu-bs.de
%         contact: Ludger Merz, DASA-Airbus GmbH, Hamburg; ludger.merz@airbus.de

	ldir = loopdir;
	if ldir == []
		ldir = 'loop';
	end

    y_ges = []; 
    t_ges = []; 
    u_ges = [];
    gutp = []; 
    for i = 1:20, 
		filename = [ldir '/loop_', num2str(i) '.mat'];
		if ~exist(filename)
			break;
		end
        comand = ['load ' ldir '/loop_', num2str(i)];
        eval(comand);
        if (size(t,1) ~= size(t_ges,1) | size(nef_u,1) ~= size(u_ges,1) ...
                         | size(nef_y,1) ~= size(y_ges,1)) & size(t_ges,1) ~= 0
            disp(['Illegal matrix size in saved data loop_' num2str(i) ' - perhaps different simulations.']);
        elseif size(t,1) ~= size(nef_u,1) | size(t,1) ~= size(nef_y,1)
            disp(['Different matrix size in saved data loop_' num2str(i) ' - perhaps error in simulation.']);
        else
            gutp = [gutp i];
            t_ges = [t_ges t]; 
            u_ges = [u_ges nef_u]; 
            y_ges = [y_ges nef_y];
        end
    end; 

    % ------------------------------------------------- 
    %  calculate the number of subplots 
    % ------------------------------------------------- 
    m = size(y_ges,2); 
    if m > 0, 
        spm = ceil( sqrt(m) ); 
        spn = ceil( m / spm ); 


        % ------------------------------------------------- 
        %  plot the function 
        % ------------------------------------------------- 
        % open new window 
        figure;
        for i=1:m, 
           subplot (spm, spn, i); 
           plot(t_ges(:,i), u_ges(:,i), 'm', t_ges(:,i), y_ges(:,i), 'c'); grid 
           title(['loop_', num2str(gutp(i))]); 
           xlabel(' '); 
           ylabel(' '); 
        end; 

        set(gcf,'windowbuttondownfcn',['nefsim1(''wbd'',''' ldir ''')']); 
        cl = uicontrol(gcf, 'style','pushbutton',... 
                       'position',[15 3 100 18],... 
                       'Callback', 'close(gcf);',... 
                       'string', 'Close'); 
    end; 
 
end 
