function [ret,x0,str,ts,xts]=sample3(t,x,u,flag);
%SAMPLE3	is the M-file description of the SIMULINK system named SAMPLE3.
%	The block-diagram can be displayed by typing: SAMPLE3.
%
%	SYS=SAMPLE3(T,X,U,FLAG) returns depending on FLAG certain
%	system values given time point, T, current state vector, X,
%	and input vector, U.
%	FLAG is used to indicate the type of output to be returned in SYS.
%
%	Setting FLAG=1 causes SAMPLE3 to return state derivatives, FLAG=2
%	discrete states, FLAG=3 system outputs and FLAG=4 next sample
%	time. For more information and other options see SFUNC.
%
%	Calling SAMPLE3 with a FLAG of zero:
%	[SIZES]=SAMPLE3([],[],[],0),  returns a vector, SIZES, which
%	contains the sizes of the state vector and other parameters.
%		SIZES(1) number of states
%		SIZES(2) number of discrete states
%		SIZES(3) number of outputs
%		SIZES(4) number of inputs
%		SIZES(5) number of roots (currently unsupported)
%		SIZES(6) direct feedthrough flag
%		SIZES(7) number of sample times
%
%	For the definition of other parameters in SIZES, see SFUNC.
%	See also, TRIM, LINMOD, LINSIM, EULER, RK23, RK45, ADAMS, GEAR.

% Note: This M-file is only used for saving graphical information;
%       after the model is loaded into memory an internal model
%       representation is used.

% the system will take on the name of this mfile:
sys = mfilename;
new_system(sys)
simver(1.3)
if (0 == (nargin + nargout))
     set_param(sys,'Location',[8,47,741,297])
     open_system(sys)
end;
set_param(sys,'algorithm',     'RK-45')
set_param(sys,'Start time',    '0.0')
set_param(sys,'Stop time',     '5')
set_param(sys,'Min step size', '0.04')
set_param(sys,'Max step size', '0.04')
set_param(sys,'Relative error','1e-3')
set_param(sys,'Return vars',   '')

add_block('built-in/Scope',[sys,'/','signal'])
set_param([sys,'/','signal'],...
		'BackGround',3,...
		'Vgain','6.000000',...
		'Hgain','5.000000',...
		'Vmax','12.000000',...
		'Hmax','10.000000',...
		'Window',[548,321,813,563])
open_system([sys,'/','signal'])
set_param([sys,'/','signal'],...
		'position',[495,17,515,43])

add_block('built-in/Mux',[sys,'/','Mux5'])
set_param([sys,'/','Mux5'],...
		'hide name',0,...
		'inputs','2',...
		'position',[420,14,450,41])

add_block('built-in/Mux',[sys,'/','Mux4'])
set_param([sys,'/','Mux4'],...
		'hide name',0,...
		'inputs','2',...
		'position',[230,14,260,41])

add_block('built-in/Scope',[sys,'/','dx'])
set_param([sys,'/','dx'],...
		'BackGround',3,...
		'Vgain','2.000000',...
		'Hgain','5.000000',...
		'Vmax','4.000000',...
		'Hmax','10.000000',...
		'Window',[5,320,270,559])
open_system([sys,'/','dx'])
set_param([sys,'/','dx'],...
		'position',[300,17,320,43])

add_block('built-in/Sum',[sys,'/','error'])
set_param([sys,'/','error'],...
		'inputs','+-',...
		'position',[155,122,170,158])

add_block('built-in/Transfer Fcn',[sys,'/','pt2'])
set_param([sys,'/','pt2'],...
		'Denominator','[0.02 0.16 1]',...
		'position',[435,122,550,158])


%     Subsystem  'Fuzzi'.

new_system([sys,'/','Fuzzi'])
set_param([sys,'/','Fuzzi'],'Location',[220,420,895,753])

add_block('built-in/Mux',[sys,'/','Fuzzi/Mux1'])
set_param([sys,'/','Fuzzi/Mux1'],...
		'inputs','2',...
		'position',[425,305,455,325])

add_block('built-in/Scope',[sys,'/','Fuzzi/Error'])
set_param([sys,'/','Fuzzi/Error'],...
		'BackGround',3,...
		'Vgain','2.000000',...
		'Hgain','5.000000',...
		'Vmax','4.000000',...
		'Hmax','10.000000',...
		'Window',[609,369,873,613],...
		'position',[475,305,495,325])

add_block('built-in/Stop Simulation',[sys,'/','Fuzzi/Stop Simulation'])
set_param([sys,'/','Fuzzi/Stop Simulation'],...
		'position',[455,365,495,385])

add_block('built-in/Demux',[sys,'/','Fuzzi/Demux'])
set_param([sys,'/','Fuzzi/Demux'],...
		'outputs','3',...
		'position',[365,295,400,335])

add_block('built-in/S-Function',[sys,'/',['Fuzzi/Nefcon ',13,'Lern-System']])
set_param([sys,'/',['Fuzzi/Nefcon ',13,'Lern-System']],...
		'function name','snefcon',...
		'position',[295,295,350,335])

add_block('built-in/Saturation',[sys,'/','Fuzzi/Saturation3'])
set_param([sys,'/','Fuzzi/Saturation3'],...
		'Lower Limit','-1',...
		'Upper Limit','1',...
		'position',[145,350,170,370])

add_block('built-in/Gain',[sys,'/','Fuzzi/GainIn3'])
set_param([sys,'/','Fuzzi/GainIn3'],...
		'Gain','0.8',...
		'position',[95,350,115,370])

add_block('built-in/Inport',[sys,'/','Fuzzi/in_3'])
set_param([sys,'/','Fuzzi/in_3'],...
		'Port','3',...
		'position',[50,350,70,370])

add_block('built-in/Saturation',[sys,'/','Fuzzi/Saturation2'])
set_param([sys,'/','Fuzzi/Saturation2'],...
		'Lower Limit','-1',...
		'Upper Limit','1',...
		'position',[145,305,170,325])

add_block('built-in/Gain',[sys,'/','Fuzzi/GainIn2'])
set_param([sys,'/','Fuzzi/GainIn2'],...
		'Gain','2',...
		'position',[95,305,115,325])

add_block('built-in/Inport',[sys,'/','Fuzzi/in_2'])
set_param([sys,'/','Fuzzi/in_2'],...
		'Port','2',...
		'position',[50,305,70,325])

add_block('built-in/Saturation',[sys,'/','Fuzzi/Saturation1'])
set_param([sys,'/','Fuzzi/Saturation1'],...
		'Lower Limit','-1',...
		'Upper Limit','1',...
		'position',[145,260,170,280])

add_block('built-in/Gain',[sys,'/','Fuzzi/GainIn1'])
set_param([sys,'/','Fuzzi/GainIn1'],...
		'position',[95,260,115,280])

add_block('built-in/Inport',[sys,'/','Fuzzi/in_1'])
set_param([sys,'/','Fuzzi/in_1'],...
		'position',[50,260,70,280])

add_block('built-in/Mux',[sys,'/','Fuzzi/Mux'])
set_param([sys,'/','Fuzzi/Mux'],...
		'inputs','3',...
		'position',[220,245,250,395])

add_block('built-in/Switch',[sys,'/','Fuzzi/Switch'])
set_param([sys,'/','Fuzzi/Switch'],...
		'Threshold','0.5',...
		'position',[315,43,340,137])

add_block('built-in/Signal Generator',[sys,'/','Fuzzi/Rauschen'])
set_param([sys,'/','Fuzzi/Rauschen'],...
		'Peak','1.000000',...
		'Peak Range','5.000000',...
		'Freq','1.000000',...
		'Freq Range','5.000000',...
		'Wave','Rnd',...
		'Units','Rads',...
		'position',[145,49,185,71])

add_block('built-in/Gain',[sys,'/','Fuzzi/Gain'])
set_param([sys,'/','Fuzzi/Gain'],...
		'Gain','0.4',...
		'position',[210,44,265,76])


%     Subsystem  'Fuzzi/Get Signal'.

new_system([sys,'/','Fuzzi/Get Signal'])
set_param([sys,'/','Fuzzi/Get Signal'],'Location',[200,498,478,742])

add_block('built-in/S-Function',[sys,'/','Fuzzi/Get Signal/S-Function1'])
set_param([sys,'/','Fuzzi/Get Signal/S-Function1'],...
		'function name','getsig',...
		'parameters','width,name',...
		'position',[65,48,115,72])

add_block('built-in/Outport',[sys,'/','Fuzzi/Get Signal/out_1'])
set_param([sys,'/','Fuzzi/Get Signal/out_1'],...
		'position',[125,50,145,70])
add_line([sys,'/','Fuzzi/Get Signal'],[120,60;120,60])
set_param([sys,'/','Fuzzi/Get Signal'],...
		'Mask Display','GETSIG',...
		'Mask Type','GEt Signal',...
		'Mask Dialogue','Put a signal into the MATLAB workspace.  Specify the signal width and name. | Signal Width: | Name (in quotes):')
set_param([sys,'/','Fuzzi/Get Signal'],...
		'Mask Translate','width=@1;name=@2;')
set_param([sys,'/','Fuzzi/Get Signal'],...
		'Mask Help','Get signal from the MATLAB workspace. To be used in conjunction with PUTSIG. Names must be entered as strings.  The code for this block is getsig.c')
set_param([sys,'/','Fuzzi/Get Signal'],...
		'Mask Entries','1\/''NEFCON_NOISE''\/')


%     Finished composite block 'Fuzzi/Get Signal'.

set_param([sys,'/','Fuzzi/Get Signal'],...
		'position',[140,90,200,130])

add_block('built-in/Constant',[sys,'/','Fuzzi/Constant1'])
set_param([sys,'/','Fuzzi/Constant1'],...
		'Value','0',...
		'position',[250,120,270,140])

add_block('built-in/Sum',[sys,'/','Fuzzi/Sum'])
set_param([sys,'/','Fuzzi/Sum'],...
		'position',[420,52,445,208])

add_block('built-in/Gain',[sys,'/','Fuzzi/GainOut'])
set_param([sys,'/','Fuzzi/GainOut'],...
		'Gain','4',...
		'position',[485,125,505,145])

add_block('built-in/Outport',[sys,'/','Fuzzi/out_1'])
set_param([sys,'/','Fuzzi/out_1'],...
		'position',[535,125,555,145])
add_line([sys,'/','Fuzzi'],[75,270;90,270])
add_line([sys,'/','Fuzzi'],[120,270;140,270])
add_line([sys,'/','Fuzzi'],[175,270;215,270])
add_line([sys,'/','Fuzzi'],[75,315;90,315])
add_line([sys,'/','Fuzzi'],[120,315;140,315])
add_line([sys,'/','Fuzzi'],[175,315;202,315;202,320;215,320])
add_line([sys,'/','Fuzzi'],[75,360;90,360])
add_line([sys,'/','Fuzzi'],[120,360;140,360])
add_line([sys,'/','Fuzzi'],[175,360;202,360;202,370;215,370])
add_line([sys,'/','Fuzzi'],[255,320;267,320;267,315;290,315])
add_line([sys,'/','Fuzzi'],[355,315;360,315])
add_line([sys,'/','Fuzzi'],[510,135;530,135])
add_line([sys,'/','Fuzzi'],[405,315;412,315;412,310;420,310])
add_line([sys,'/','Fuzzi'],[460,315;470,315])
add_line([sys,'/','Fuzzi'],[405,330;435,330;435,375;450,375])
add_line([sys,'/','Fuzzi'],[345,90;415,90])
add_line([sys,'/','Fuzzi'],[275,130;287,130;287,120;310,120])
add_line([sys,'/','Fuzzi'],[270,60;310,60])
add_line([sys,'/','Fuzzi'],[190,60;205,60])
add_line([sys,'/','Fuzzi'],[450,130;460,130;460,135;480,135])
add_line([sys,'/','Fuzzi'],[405,300;415,170])
set_param([sys,'/','Fuzzi'],...
		'Mask Display','NEFCON\nFuzzy')


%     Finished composite block 'Fuzzi'.

set_param([sys,'/','Fuzzi'],...
		'BackGround',2,...
		'hide name',0,...
		'position',[320,95,380,185])

add_block('built-in/Scope',[sys,'/','out'])
set_param([sys,'/','out'],...
		'BackGround',3,...
		'Vgain','2.000000',...
		'Hgain','5.000000',...
		'Vmax','4.000000',...
		'Hmax','10.000000',...
		'Window',[275,320,541,559])
open_system([sys,'/','out'])
set_param([sys,'/','out'],...
		'position',[625,77,645,103])

add_block('built-in/Mux',[sys,'/','Mux2'])
set_param([sys,'/','Mux2'],...
		'hide name',0,...
		'inputs','2',...
		'position',[570,74,600,101])

add_block('built-in/Derivative',[sys,'/','Derivative'])
set_param([sys,'/','Derivative'],...
		'position',[220,126,250,154])


%     Subsystem  'Bounded SigGen'.

new_system([sys,'/','Bounded SigGen'])
set_param([sys,'/','Bounded SigGen'],'Location',[228,66,700,333])

add_block('built-in/Switch',[sys,'/','Bounded SigGen/Switch'])
set_param([sys,'/','Bounded SigGen/Switch'],...
		'Threshold','0.5',...
		'position',[205,23,230,117])

add_block('built-in/Signal Generator',[sys,'/','Bounded SigGen/Rauschen'])
set_param([sys,'/','Bounded SigGen/Rauschen'],...
		'Peak','1.000000',...
		'Peak Range','5.000000',...
		'Freq','1.000000',...
		'Freq Range','5.000000',...
		'Wave','Rnd',...
		'Units','Rads',...
		'position',[35,29,75,51])

add_block('built-in/Gain',[sys,'/','Bounded SigGen/Gain'])
set_param([sys,'/','Bounded SigGen/Gain'],...
		'Gain','0.4',...
		'position',[100,24,155,56])


%     Subsystem  'Bounded SigGen/Get Signal'.

new_system([sys,'/','Bounded SigGen/Get Signal'])
set_param([sys,'/','Bounded SigGen/Get Signal'],'Location',[200,498,478,742])

add_block('built-in/Outport',[sys,'/','Bounded SigGen/Get Signal/out_1'])
set_param([sys,'/','Bounded SigGen/Get Signal/out_1'],...
		'position',[125,50,145,70])

add_block('built-in/S-Function',[sys,'/','Bounded SigGen/Get Signal/S-Function1'])
set_param([sys,'/','Bounded SigGen/Get Signal/S-Function1'],...
		'function name','getsig',...
		'parameters','width,name',...
		'position',[65,48,115,72])
add_line([sys,'/','Bounded SigGen/Get Signal'],[120,60;120,60])
set_param([sys,'/','Bounded SigGen/Get Signal'],...
		'Mask Display','GETSIG',...
		'Mask Type','GEt Signal',...
		'Mask Dialogue','Put a signal into the MATLAB workspace.  Specify the signal width and name. | Signal Width: | Name (in quotes):')
set_param([sys,'/','Bounded SigGen/Get Signal'],...
		'Mask Translate','width=@1;name=@2;')
set_param([sys,'/','Bounded SigGen/Get Signal'],...
		'Mask Help','Get signal from the MATLAB workspace. To be used in conjunction with PUTSIG. Names must be entered as strings.  The code for this block is getsig.c')
set_param([sys,'/','Bounded SigGen/Get Signal'],...
		'Mask Entries','1\/''NEFCON_NOISE''\/')


%     Finished composite block 'Bounded SigGen/Get Signal'.

set_param([sys,'/','Bounded SigGen/Get Signal'],...
		'position',[30,70,90,110])

add_block('built-in/Constant',[sys,'/','Bounded SigGen/Constant1'])
set_param([sys,'/','Bounded SigGen/Constant1'],...
		'Value','0',...
		'position',[140,100,160,120])

add_block('built-in/Inport',[sys,'/','Bounded SigGen/in_1'])
set_param([sys,'/','Bounded SigGen/in_1'],...
		'position',[15,190,35,210])

add_block('built-in/Derivative',[sys,'/','Bounded SigGen/Derivative'])
set_param([sys,'/','Bounded SigGen/Derivative'],...
		'position',[70,230,100,260])

add_block('built-in/Mux',[sys,'/','Bounded SigGen/Mux'])
set_param([sys,'/','Bounded SigGen/Mux'],...
		'inputs','2',...
		'position',[120,190,150,250])

add_block('built-in/S-Function',[sys,'/','Bounded SigGen/S-function'])
set_param([sys,'/','Bounded SigGen/S-function'],...
		'function name','snefsign',...
		'position',[175,210,235,230])

add_block('built-in/Demux',[sys,'/','Bounded SigGen/Demux'])
set_param([sys,'/','Bounded SigGen/Demux'],...
		'outputs','3',...
		'position',[260,200,280,240])

add_block('built-in/Sum',[sys,'/','Bounded SigGen/Sum'])
set_param([sys,'/','Bounded SigGen/Sum'],...
		'position',[310,32,335,188])

add_block('built-in/Gain',[sys,'/','Bounded SigGen/Gain1'])
set_param([sys,'/','Bounded SigGen/Gain1'],...
		'position',[355,94,410,126])

add_block('built-in/Outport',[sys,'/','Bounded SigGen/out_1'])
set_param([sys,'/','Bounded SigGen/out_1'],...
		'position',[425,100,445,120])
add_line([sys,'/','Bounded SigGen'],[40,200;57,200;57,245;65,245])
add_line([sys,'/','Bounded SigGen'],[40,200;90,200;90,205;115,205])
add_line([sys,'/','Bounded SigGen'],[105,245;109,245;109,235;115,235])
add_line([sys,'/','Bounded SigGen'],[155,220;170,220])
add_line([sys,'/','Bounded SigGen'],[240,220;255,220])
add_line([sys,'/','Bounded SigGen'],[285,205;292,205;292,150;305,150])
add_line([sys,'/','Bounded SigGen'],[80,40;95,40])
add_line([sys,'/','Bounded SigGen'],[160,40;200,40])
add_line([sys,'/','Bounded SigGen'],[165,110;177,110;177,100;200,100])
add_line([sys,'/','Bounded SigGen'],[235,70;305,70])
add_line([sys,'/','Bounded SigGen'],[340,110;350,110])
add_line([sys,'/','Bounded SigGen'],[415,110;420,110])
add_line([sys,'/','Bounded SigGen'],[95,90;140,90;140,70;200,70])
set_param([sys,'/','Bounded SigGen'],...
		'Mask Display','NEFCON\nBounded\nSigGen',...
		'Mask Dialogue','eval(''nefsign'');')


%     Finished composite block 'Bounded SigGen'.

set_param([sys,'/','Bounded SigGen'],...
		'BackGround',2,...
		'hide name',0,...
		'position',[30,105,100,155])


%     Subsystem  ['Nefcon',13,'System'].

new_system([sys,'/',['Nefcon',13,'System']])
set_param([sys,'/',['Nefcon',13,'System']],'Location',[350,404,888,586])
set_param([sys,'/',['Nefcon',13,'System']],...
		'Mask Display','Nefcon\nSystem',...
		'Mask Type','Nefcon',...
		'Mask Dialogue','eval(''nefgui'')')


%     Finished composite block ['Nefcon',13,'System'].

set_param([sys,'/',['Nefcon',13,'System']],...
		'BackGround',2,...
		'Drop Shadow',4,...
		'position',[666,9,721,61])

add_block('built-in/Integrator',[sys,'/','Integrator'])
set_param([sys,'/','Integrator'],...
		'position',[195,279,220,301])

add_block('built-in/Gain',[sys,'/','Gain4'])
set_param([sys,'/','Gain4'],...
		'Gain','4',...
		'position',[280,278,300,302])

add_block('built-in/To Workspace',[sys,'/','Response'])
set_param([sys,'/','Response'],...
		'BackGround',2,...
		'mat-name','nef_y',...
		'buffer','10000',...
		'Mask Display','nef_y',...
		'position',[585,130,645,150])

add_block('built-in/To Workspace',[sys,'/','Signal'])
set_param([sys,'/','Signal'],...
		'BackGround',2,...
		'mat-name','nef_u',...
		'buffer','10000',...
		'Mask Display','nef_u',...
		'position',[130,40,190,60])
add_line(sys,[105,130;150,130])
add_line(sys,[605,90;620,90])
add_line(sys,[175,140;195,140;195,35;225,35])
add_line(sys,[555,140;565,95])
add_line(sys,[255,140;315,140])
add_line(sys,[175,140;215,140])
add_line(sys,[555,140;555,230;130,230;130,150;150,150])
add_line(sys,[385,140;430,140])
add_line(sys,[265,30;295,30])
add_line(sys,[555,140;580,140])
add_line(sys,[195,110;315,110])
add_line(sys,[130,230;15,230;25,130])
add_line(sys,[455,30;490,30])
add_line(sys,[405,140;415,35])
add_line(sys,[115,130;115,170;315,170])
add_line(sys,[115,130;115,80;565,80])
add_line(sys,[115,85;125,50])
add_line(sys,[225,290;275,290])

drawnow

% Return any arguments.
if (nargin | nargout)
	% Must use feval here to access system in memory
	if (nargin > 3)
		if (flag == 0)
			eval(['[ret,x0,str,ts,xts]=',sys,'(t,x,u,flag);'])
		else
			eval(['ret =', sys,'(t,x,u,flag);'])
		end
	else
		[ret,x0,str,ts,xts] = feval(sys);
	end
else
	drawnow % Flash up the model and execute load callback
end
