function [ret,x0,str,ts,xts]=sample4(t,x,u,flag);
%SAMPLE4	is the M-file description of the SIMULINK system named SAMPLE4.
%	The block-diagram can be displayed by typing: SAMPLE4.
%
%	SYS=SAMPLE4(T,X,U,FLAG) returns depending on FLAG certain
%	system values given time point, T, current state vector, X,
%	and input vector, U.
%	FLAG is used to indicate the type of output to be returned in SYS.
%
%	Setting FLAG=1 causes SAMPLE4 to return state derivatives, FLAG=2
%	discrete states, FLAG=3 system outputs and FLAG=4 next sample
%	time. For more information and other options see SFUNC.
%
%	Calling SAMPLE4 with a FLAG of zero:
%	[SIZES]=SAMPLE4([],[],[],0),  returns a vector, SIZES, which
%	contains the sizes of the state vector and other parameters.
%		SIZES(1) number of states
%		SIZES(2) number of discrete states
%		SIZES(3) number of outputs
%		SIZES(4) number of inputs
%		SIZES(5) number of roots (currently unsupported)
%		SIZES(6) direct feedthrough flag
%		SIZES(7) number of sample times
%
%	For the definition of other parameters in SIZES, see SFUNC.
%	See also, TRIM, LINMOD, LINSIM, EULER, RK23, RK45, ADAMS, GEAR.

% Note: This M-file is only used for saving graphical information;
%       after the model is loaded into memory an internal model
%       representation is used.

% the system will take on the name of this mfile:
sys = mfilename;
new_system(sys)
simver(1.3)
if (0 == (nargin + nargout))
     set_param(sys,'Location',[192,262,766,626])
     open_system(sys)
end;
set_param(sys,'algorithm',     'RK-45')
set_param(sys,'Start time',    '0.0')
set_param(sys,'Stop time',     '5')
set_param(sys,'Min step size', '0.03')
set_param(sys,'Max step size', '0.03')
set_param(sys,'Relative error','1e-3')
set_param(sys,'Return vars',   '')
set_param(sys,'Load callback','initcp');
set_param(sys,'AssignWideVectorLines','on');

add_block('built-in/S-Function',[sys,'/','Animation'])
set_param([sys,'/','Animation'],...
		'function name','animcp',...
		'Mask Display','',...
		'position',[380,34,435,66])

add_block('built-in/Mux',[sys,'/','Mux'])
set_param([sys,'/','Mux'],...
		'orientation',3,...
		'hide name',0,...
		'position',[300,70,340,105])


%     Subsystem  ['Double click',13,'on this for demo.5'].

new_system([sys,'/',['Double click',13,'on this for demo.5']])
set_param([sys,'/',['Double click',13,'on this for demo.5']],'Location',[-10,380,117,533])
set_param([sys,'/',['Double click',13,'on this for demo.5']],...
		'Mask Display','Variable Initialization',...
		'Mask Dialogue','eval(''initcp'')')


%     Finished composite block ['Double click',13,'on this for demo.5'].

set_param([sys,'/',['Double click',13,'on this for demo.5']],...
		'hide name',0,...
		'Drop Shadow',4,...
		'position',[15,242,156,275])


%     Subsystem  ['Cart & Pole',13,'Dynamics'].

new_system([sys,'/',['Cart & Pole',13,'Dynamics']])
set_param([sys,'/',['Cart & Pole',13,'Dynamics']],'Location',[362,320,1162,625])

add_block('built-in/Integrator',[sys,'/',['Cart & Pole',13,'Dynamics/theta dot']])
set_param([sys,'/',['Cart & Pole',13,'Dynamics/theta dot']],...
		'Initial','init_cond(2)',...
		'position',[435,85,455,105])

add_block('built-in/Fcn',[sys,'/',['Cart & Pole',13,'Dynamics/Fcn1']])
set_param([sys,'/',['Cart & Pole',13,'Dynamics/Fcn1']],...
		'hide name',0,...
		'Expr','(g*u(2)+u(3)*((-u(1)-m*l*u(4)*u(4)*u(2))/(mc+m)))/(l*(4/3-(m*u(3)*u(3))/(mc+m)))',...
		'position',[350,85,390,105])

add_block('built-in/Outport',[sys,'/',['Cart & Pole',13,'Dynamics/out_4']])
set_param([sys,'/',['Cart & Pole',13,'Dynamics/out_4']],...
		'Port','4',...
		'position',[675,205,695,225])

add_block('built-in/Outport',[sys,'/',['Cart & Pole',13,'Dynamics/out_3']])
set_param([sys,'/',['Cart & Pole',13,'Dynamics/out_3']],...
		'Port','3',...
		'position',[675,165,695,185])

add_block('built-in/Outport',[sys,'/',['Cart & Pole',13,'Dynamics/out_2']])
set_param([sys,'/',['Cart & Pole',13,'Dynamics/out_2']],...
		'Port','2',...
		'position',[675,125,695,145])

add_block('built-in/Outport',[sys,'/',['Cart & Pole',13,'Dynamics/out_1']])
set_param([sys,'/',['Cart & Pole',13,'Dynamics/out_1']],...
		'position',[670,85,690,105])

add_block('built-in/Fcn',[sys,'/',['Cart & Pole',13,'Dynamics/Fcn5']])
set_param([sys,'/',['Cart & Pole',13,'Dynamics/Fcn5']],...
		'hide name',0,...
		'Expr','cos(u[1])',...
		'position',[145,118,200,142])

add_block('built-in/Fcn',[sys,'/',['Cart & Pole',13,'Dynamics/Fcn4']])
set_param([sys,'/',['Cart & Pole',13,'Dynamics/Fcn4']],...
		'hide name',0,...
		'position',[145,89,200,111])

add_block('built-in/Integrator',[sys,'/',['Cart & Pole',13,'Dynamics/theta']])
set_param([sys,'/',['Cart & Pole',13,'Dynamics/theta']],...
		'Initial','init_cond(1)',...
		'position',[505,85,525,105])

add_block('built-in/Integrator',[sys,'/',['Cart & Pole',13,'Dynamics/x']])
set_param([sys,'/',['Cart & Pole',13,'Dynamics/x']],...
		'Initial','init_cond(3)',...
		'position',[570,220,590,240])

add_block('built-in/Inport',[sys,'/',['Cart & Pole',13,'Dynamics/in_1']])
set_param([sys,'/',['Cart & Pole',13,'Dynamics/in_1']],...
		'position',[205,60,225,80])

add_block('built-in/Mux',[sys,'/',['Cart & Pole',13,'Dynamics/Mux1']])
set_param([sys,'/',['Cart & Pole',13,'Dynamics/Mux1']],...
		'hide name',0,...
		'position',[280,65,315,120])

add_block('built-in/Integrator',[sys,'/',['Cart & Pole',13,'Dynamics/x dot']])
set_param([sys,'/',['Cart & Pole',13,'Dynamics/x dot']],...
		'Initial','init_cond(4)',...
		'position',[510,220,530,240])

add_block('built-in/Fcn',[sys,'/',['Cart & Pole',13,'Dynamics/Fcn2']])
set_param([sys,'/',['Cart & Pole',13,'Dynamics/Fcn2']],...
		'hide name',0,...
		'Expr','(u(1)+m*l*(u(4)*u(4)*u(2)-u(5)*u(3)))/(mc+m)',...
		'position',[450,220,490,240])

add_block('built-in/Mux',[sys,'/',['Cart & Pole',13,'Dynamics/Mux2']])
set_param([sys,'/',['Cart & Pole',13,'Dynamics/Mux2']],...
		'hide name',0,...
		'inputs','[4,1]',...
		'position',[400,208,430,252])
add_line([sys,'/',['Cart & Pole',13,'Dynamics']],[530,95;570,95;570,30;125,30;125,130;140,130])
add_line([sys,'/',['Cart & Pole',13,'Dynamics']],[125,100;140,100])
add_line([sys,'/',['Cart & Pole',13,'Dynamics']],[320,95;330,95;330,220;395,220])
add_line([sys,'/',['Cart & Pole',13,'Dynamics']],[205,130;240,130;240,100;275,100])
add_line([sys,'/',['Cart & Pole',13,'Dynamics']],[205,100;230,100;230,85;275,85])
add_line([sys,'/',['Cart & Pole',13,'Dynamics']],[460,95;500,95])
add_line([sys,'/',['Cart & Pole',13,'Dynamics']],[475,95;475,135;670,135])
add_line([sys,'/',['Cart & Pole',13,'Dynamics']],[475,135;255,135;255,115;275,115])
add_line([sys,'/',['Cart & Pole',13,'Dynamics']],[395,95;430,95])
add_line([sys,'/',['Cart & Pole',13,'Dynamics']],[415,95;415,125;370,125;370,240;395,240])
add_line([sys,'/',['Cart & Pole',13,'Dynamics']],[535,230;565,230])
add_line([sys,'/',['Cart & Pole',13,'Dynamics']],[495,230;505,230])
add_line([sys,'/',['Cart & Pole',13,'Dynamics']],[435,230;445,230])
add_line([sys,'/',['Cart & Pole',13,'Dynamics']],[320,95;345,95])
add_line([sys,'/',['Cart & Pole',13,'Dynamics']],[535,230;550,230;550,215;670,215])
add_line([sys,'/',['Cart & Pole',13,'Dynamics']],[595,230;620,230;620,175;670,175])
add_line([sys,'/',['Cart & Pole',13,'Dynamics']],[230,70;275,70])
add_line([sys,'/',['Cart & Pole',13,'Dynamics']],[570,95;665,95])
set_param([sys,'/',['Cart & Pole',13,'Dynamics']],...
		'Mask Display','plot(-4,-1,4,6,[0 3 2.8 -0.2 0],[1 5 5.15 1.15 1],[-1 -1 1 1 -1],[1 0 0 1 1],[-3.5 3.5],[0 0])',...
		'Mask Type','Cart & Pole')
set_param([sys,'/',['Cart & Pole',13,'Dynamics']],...
		'Mask Dialogue','Inverted Pendulum (cart & pole)|Initial Conditions (angle, angular velocity, cart position and cart velocity):|Physical Specifications (pole length, pole mass, cart mass and g):')
set_param([sys,'/',['Cart & Pole',13,'Dynamics']],...
		'Mask Translate','init_cond = @1; specs = @2;l=specs(1)/2;m=specs(2);mc=specs(3);g=specs(4);',...
		'Mask Help','Inverted Pendulum',...
		'Mask Entries','[0, 0, 0, 0]\/[1.0, 0.1, 1.0, 9.8]\/')


%     Finished composite block ['Cart & Pole',13,'Dynamics'].

set_param([sys,'/',['Cart & Pole',13,'Dynamics']],...
		'position',[240,155,290,210])

add_block('built-in/Constant',[sys,'/',['Target Position',13,'(Mouse-Driven)']])
set_param([sys,'/',['Target Position',13,'(Mouse-Driven)']],...
		'orientation',3,...
		'move name',0,...
		'Value','0.153846',...
		'position',[102,185,128,205])

add_block('built-in/Constant',[sys,'/','Constant'])
set_param([sys,'/','Constant'],...
		'orientation',3,...
		'move name',0,...
		'position',[81,155,99,175])

add_block('built-in/Switch',[sys,'/','Switch'])
set_param([sys,'/','Switch'],...
		'position',[140,114,165,146])

add_block('built-in/Signal Generator',[sys,'/','Target Position'])
set_param([sys,'/','Target Position'],...
		'Peak','1.500000',...
		'Peak Range','7.500000',...
		'Freq','0.628320',...
		'Freq Range','1.000000',...
		'Wave','Sqr',...
		'Units','Rads',...
		'position',[15,103,60,137])

add_block('built-in/Sum',[sys,'/','Sum1'])
set_param([sys,'/','Sum1'],...
		'hide name',0,...
		'inputs','-+',...
		'position',[190,175,210,195])

add_block('built-in/Mux',[sys,'/','Mux3'])
set_param([sys,'/','Mux3'],...
		'hide name',0,...
		'inputs','2',...
		'position',[430,189,460,216])

add_block('built-in/Scope',[sys,'/','Scope3'])
set_param([sys,'/','Scope3'],...
		'hide name',0,...
		'Vgain','1.000000',...
		'Hgain','10.000000',...
		'Vmax','2.000000',...
		'Hmax','20.000000',...
		'Window',[241,540,521,760],...
		'position',[480,192,500,218])

add_block('built-in/Sum',[sys,'/','Sum'])
set_param([sys,'/','Sum'],...
		'orientation',1,...
		'hide name',0,...
		'inputs','+-',...
		'position',[375,220,395,240])

add_block('built-in/Signal Generator',[sys,'/','Noise'])
set_param([sys,'/','Noise'],...
		'Peak','0.500000',...
		'Peak Range','2.500000',...
		'Freq','2.000000',...
		'Freq Range','3.278689',...
		'Wave','Saw',...
		'Units','Rads',...
		'position',[115,28,160,62])


%     Subsystem  'Fuzzi'.

new_system([sys,'/','Fuzzi'])
set_param([sys,'/','Fuzzi'],'Location',[100,100,600,400])

add_block('built-in/Mux',[sys,'/','Fuzzi/Mux'])
set_param([sys,'/','Fuzzi/Mux'],...
		'position',[205,52,235,248])

add_block('built-in/Inport',[sys,'/','Fuzzi/in_1'])
set_param([sys,'/','Fuzzi/in_1'],...
		'position',[35,65,55,85])

add_block('built-in/Gain',[sys,'/','Fuzzi/GainIn1'])
set_param([sys,'/','Fuzzi/GainIn1'],...
		'Gain','3',...
		'position',[80,65,100,85])

add_block('built-in/Saturation',[sys,'/','Fuzzi/Saturation1'])
set_param([sys,'/','Fuzzi/Saturation1'],...
		'Lower Limit','-1',...
		'Upper Limit','1',...
		'position',[130,65,155,85])

add_block('built-in/Inport',[sys,'/','Fuzzi/in_2'])
set_param([sys,'/','Fuzzi/in_2'],...
		'Port','2',...
		'position',[35,110,55,130])

add_block('built-in/Gain',[sys,'/','Fuzzi/GainIn2'])
set_param([sys,'/','Fuzzi/GainIn2'],...
		'position',[80,110,100,130])

add_block('built-in/Saturation',[sys,'/','Fuzzi/Saturation2'])
set_param([sys,'/','Fuzzi/Saturation2'],...
		'Lower Limit','-1',...
		'Upper Limit','1',...
		'position',[130,110,155,130])

add_block('built-in/Inport',[sys,'/','Fuzzi/in_3'])
set_param([sys,'/','Fuzzi/in_3'],...
		'Port','3',...
		'position',[35,155,55,175])

add_block('built-in/Gain',[sys,'/','Fuzzi/GainIn3'])
set_param([sys,'/','Fuzzi/GainIn3'],...
		'Gain','0.33',...
		'position',[80,155,100,175])

add_block('built-in/Saturation',[sys,'/','Fuzzi/Saturation3'])
set_param([sys,'/','Fuzzi/Saturation3'],...
		'Lower Limit','-1',...
		'Upper Limit','1',...
		'position',[130,155,155,175])

add_block('built-in/Inport',[sys,'/','Fuzzi/in_4'])
set_param([sys,'/','Fuzzi/in_4'],...
		'Port','4',...
		'position',[35,200,55,220])

add_block('built-in/Gain',[sys,'/','Fuzzi/GainIn4'])
set_param([sys,'/','Fuzzi/GainIn4'],...
		'Gain','0.33',...
		'position',[80,200,100,220])

add_block('built-in/Saturation',[sys,'/','Fuzzi/Saturation4'])
set_param([sys,'/','Fuzzi/Saturation4'],...
		'Lower Limit','-1',...
		'Upper Limit','1',...
		'position',[130,200,155,220])

add_block('built-in/S-Function',[sys,'/',['Fuzzi/Nefcon ',13,'Lern-System']])
set_param([sys,'/',['Fuzzi/Nefcon ',13,'Lern-System']],...
		'function name','snefcon',...
		'position',[280,120,335,160])

add_block('built-in/Demux',[sys,'/','Fuzzi/Demux'])
set_param([sys,'/','Fuzzi/Demux'],...
		'outputs','3',...
		'position',[350,120,385,160])

add_block('built-in/Gain',[sys,'/','Fuzzi/GainOut'])
set_param([sys,'/','Fuzzi/GainOut'],...
		'Gain','10',...
		'position',[410,90,430,110])

add_block('built-in/Outport',[sys,'/','Fuzzi/out_1'])
set_param([sys,'/','Fuzzi/out_1'],...
		'position',[460,90,480,110])

add_block('built-in/Stop Simulation',[sys,'/','Fuzzi/Stop Simulation'])
set_param([sys,'/','Fuzzi/Stop Simulation'],...
		'position',[440,190,480,210])

add_block('built-in/Scope',[sys,'/','Fuzzi/Error'])
set_param([sys,'/','Fuzzi/Error'],...
		'BackGround',3,...
		'Vgain','2.000000',...
		'Hgain','5.000000',...
		'Vmax','4.000000',...
		'Hmax','10.000000',...
		'Window',[100,100,380,320],...
		'position',[460,130,480,150])

add_block('built-in/Mux',[sys,'/','Fuzzi/Mux1'])
set_param([sys,'/','Fuzzi/Mux1'],...
		'inputs','2',...
		'position',[410,130,440,150])
add_line([sys,'/','Fuzzi'],[60,75;75,75])
add_line([sys,'/','Fuzzi'],[105,75;125,75])
add_line([sys,'/','Fuzzi'],[160,75;200,75])
add_line([sys,'/','Fuzzi'],[60,120;75,120])
add_line([sys,'/','Fuzzi'],[105,120;125,120])
add_line([sys,'/','Fuzzi'],[160,120;187,120;187,125;200,125])
add_line([sys,'/','Fuzzi'],[60,165;75,165])
add_line([sys,'/','Fuzzi'],[105,165;125,165])
add_line([sys,'/','Fuzzi'],[160,165;187,165;187,175;200,175])
add_line([sys,'/','Fuzzi'],[60,210;75,210])
add_line([sys,'/','Fuzzi'],[105,210;125,210])
add_line([sys,'/','Fuzzi'],[160,210;187,210;187,225;200,225])
add_line([sys,'/','Fuzzi'],[240,150;252,150;252,140;275,140])
add_line([sys,'/','Fuzzi'],[340,140;345,140])
add_line([sys,'/','Fuzzi'],[390,125;395,125;405,100])
add_line([sys,'/','Fuzzi'],[435,100;455,100])
add_line([sys,'/','Fuzzi'],[390,140;397,140;397,135;405,135])
add_line([sys,'/','Fuzzi'],[445,140;455,140])
add_line([sys,'/','Fuzzi'],[390,155;420,155;420,200;435,200])
set_param([sys,'/','Fuzzi'],...
		'Mask Display','NEFCON\nFuzzy')


%     Finished composite block 'Fuzzi'.

set_param([sys,'/','Fuzzi'],...
		'orientation',2,...
		'BackGround',2,...
		'hide name',0,...
		'position',[235,245,295,335])

add_block('built-in/Scope',[sys,'/','Scope'])
set_param([sys,'/','Scope'],...
		'hide name',0,...
		'Vgain','2.000000',...
		'Hgain','10.000000',...
		'Vmax','4.000000',...
		'Hmax','20.000000',...
		'Window',[72,525,352,745],...
		'position',[475,127,495,153])

add_block('built-in/Mux',[sys,'/','Mux2'])
set_param([sys,'/','Mux2'],...
		'hide name',0,...
		'inputs','2',...
		'position',[430,124,460,151])


%     Subsystem  ['Nefcon',13,'System'].

new_system([sys,'/',['Nefcon',13,'System']])
set_param([sys,'/',['Nefcon',13,'System']],'Location',[350,404,888,586])
set_param([sys,'/',['Nefcon',13,'System']],...
		'Mask Display','Nefcon\nSystem',...
		'Mask Type','Nefcon',...
		'Mask Dialogue','eval(''nefgui'')')


%     Finished composite block ['Nefcon',13,'System'].

set_param([sys,'/',['Nefcon',13,'System']],...
		'BackGround',2,...
		'Drop Shadow',4,...
		'position',[485,9,540,61])

add_block('built-in/Scope',[sys,'/','Scope2'])
set_param([sys,'/','Scope2'],...
		'hide name',0,...
		'Vgain','1.000000',...
		'Hgain','10.000000',...
		'Vmax','2.000000',...
		'Hmax','20.000000',...
		'Window',[188,491,468,711],...
		'position',[215,32,235,58])
add_line(sys,[295,190;380,190;380,215])
add_line(sys,[295,160;415,160;415,260;300,260])
add_line(sys,[170,130;390,130;390,215])
add_line(sys,[305,160;305,110])
add_line(sys,[315,190;315,110])
add_line(sys,[335,130;335,110])
add_line(sys,[320,65;320,50;375,50])
add_line(sys,[465,140;470,140])
add_line(sys,[115,180;115,140;135,140])
add_line(sys,[90,150;90,130;135,130])
add_line(sys,[65,120;135,120])
add_line(sys,[390,130;425,130])
add_line(sys,[380,190;380,145;425,145])
add_line(sys,[215,185;235,185])
add_line(sys,[215,185;220,185;220,145;325,145;325,110])
add_line(sys,[165,45;210,45])
add_line(sys,[465,205;475,205])
add_line(sys,[295,175;400,175;400,195;425,195])
add_line(sys,[415,210;425,210])
add_line(sys,[400,185;400,280;300,280])
add_line(sys,[385,245;385,300;300,300])
add_line(sys,[295,205;365,205;365,320;300,320])
add_line(sys,[230,290;165,290;165,190;185,190])
add_line(sys,[175,45;185,180])

drawnow

% Return any arguments.
if (nargin | nargout)
	% Must use feval here to access system in memory
	if (nargin > 3)
		if (flag == 0)
			eval(['[ret,x0,str,ts,xts]=',sys,'(t,x,u,flag);'])
		else
			eval(['ret =', sys,'(t,x,u,flag);'])
		end
	else
		[ret,x0,str,ts,xts] = feval(sys);
	end
else
	drawnow % Flash up the model and execute load callback
end
